@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ev-file-helpers.h 2858 2008-01-25 12:30:28Z carlosgc $
+ *  $Id: ev-file-helpers.h 3279 2008-11-29 12:09:10Z carlosgc $
  */
 
 #ifndef EV_FILE_HELPERS_H
@@ -50,6 +50,10 @@ gboolean     ev_xfer_uri_simple       (const char        *from,
 				       const char        *to,
 				       GError           **error);
 
+gchar       *ev_file_get_mime_type    (const gchar       *uri,
+				       gboolean           fast,
+				       GError           **error);
+
 gchar       *ev_file_uncompress       (const gchar       *uri,
 				       EvCompressionType  type,
 				       GError           **error);
